# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictInt, StrictStr, conint

class UnlockSpec(BaseModel):
    """
    Course-builder drip default: subset of the rule vocabulary (unlock side only).  # noqa: E501
    """
    delay_ms: Optional[conint(strict=True, ge=0)] = 0
    align_cron: Optional[StrictStr] = None
    starts_at: Optional[StrictInt] = None
    timezone: Optional[StrictStr] = None
    __properties = ["delay_ms", "align_cron", "starts_at", "timezone"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UnlockSpec:
        """Create an instance of UnlockSpec from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if align_cron (nullable) is None
        # and __fields_set__ contains the field
        if self.align_cron is None and "align_cron" in self.__fields_set__:
            _dict['align_cron'] = None

        # set to None if starts_at (nullable) is None
        # and __fields_set__ contains the field
        if self.starts_at is None and "starts_at" in self.__fields_set__:
            _dict['starts_at'] = None

        # set to None if timezone (nullable) is None
        # and __fields_set__ contains the field
        if self.timezone is None and "timezone" in self.__fields_set__:
            _dict['timezone'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UnlockSpec:
        """Create an instance of UnlockSpec from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UnlockSpec.parse_obj(obj)

        _obj = UnlockSpec.parse_obj({
            "delay_ms": obj.get("delay_ms") if obj.get("delay_ms") is not None else 0,
            "align_cron": obj.get("align_cron"),
            "starts_at": obj.get("starts_at"),
            "timezone": obj.get("timezone")
        })
        return _obj


